@@ -28,6 +28,14 @@
 #include "ap_UnixApp.h"
 #endif
 
+#ifdef HAVE_GNOME
+#include <gnome.h>
+#include <libbonoboui.h>
+#include <libgnomevfs/gnome-vfs.h>
+#include <bonobo/bonobo-macros.h>
+#include <bonobo/bonobo-object.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* c++ */
@@ -53,7 +61,7 @@ extern "C" {
   typedef gboolean (*Abi_CharPtr__Bool_EditMethod) (AbiWidget *, const char *);
   
   /* 
-   *  only here for completeness in that that we might want to 
+   * Only here for completeness in that that we might want to 
    * add signals (such as "saved") later
    */
   typedef gboolean (*AbiSignal) (AbiWidget *, gpointer closure);
@@ -186,22 +194,39 @@ extern "C" {
   };
 	
   /* the public API */
-  GtkWidget * abi_widget_new (void);
-  GtkWidget * abi_widget_new_with_file (const gchar * file);
-  GtkType     abi_widget_get_type	(void);
-  void        abi_widget_map_to_screen(AbiWidget * widget);
-  void        abi_widget_turn_on_cursor(AbiWidget * widget);
-  
+	GtkWidget * abi_widget_new (void);
+	GtkWidget * abi_widget_new_with_file (const gchar * file);
+	GtkType     abi_widget_get_type	(void);
+	void        abi_widget_map_to_screen(AbiWidget * widget);
+	void        abi_widget_turn_on_cursor(AbiWidget * widget);
+	void abi_widget_set_property(GObject  *object,
+								 guint	arg_id,
+								 const GValue *arg,
+								 GParamSpec *pspec);
+ 
+	void abi_widget_get_property(GObject  *object,
+								 guint arg_id,
+								 GValue     *arg,
+								 GParamSpec *pspec);
+
   gboolean    abi_widget_invoke(AbiWidget * w, const char * mthdName);    
   gboolean    abi_widget_invoke_ex (AbiWidget * w, const char *mthdName, 
 				    const char * data, gint32 x, gint32 y);
   
   void        abi_widget_draw(AbiWidget * w);
-  
+
+  gboolean abi_widget_save ( AbiWidget * w, const char * fname );
+  gboolean abi_widget_save_ext ( AbiWidget * w, const char * fname,
+				 const char * extension ) ;
+#ifdef HAVE_GNOME
+	void        abi_widget_set_Bonobo_uic(AbiWidget * abi,BonoboUIComponent * uic);
+    BonoboUIComponent * abi_widget_get_Bonobo_uic(AbiWidget * abi);  
+#endif
 #ifdef ABIWORD_INTERNAL
   /* these functions are used by abiword internally and really aren't exported to the rest of the world */
   GtkWidget * abi_widget_new_with_app (AP_UnixApp * pApp);
   GtkWidget * abi_widget_new_with_app_file (AP_UnixApp * pApp,const gchar * file);
+  XAP_Frame * abi_widget_get_frame ( AbiWidget * w ) ;
 #endif
   
 #ifdef __cplusplus
