@@ -26,31 +26,43 @@
 #ifndef AP_UNIXAPP_H
 #define AP_UNIXAPP_H
 
+#include <popt.h>
 #include "ut_bytebuf.h"
 #include "xap_Args.h"
+#include "ap_App.h"
 #include "ap_UnixPrefs.h"
 #include "ap_UnixClipboard.h"
 #include "pt_Types.h"
 
-#ifdef HAVE_GNOME
+#if 0//def HAVE_GNOME
 #include "xap_UnixGnomeApp.h"
 #define XAP_UNIXBASEAPP XAP_UnixGnomeApp
 #else
 #include "xap_UnixApp.h"
 #define XAP_UNIXBASEAPP XAP_UnixApp
 #endif
+	
+
+//#define LOGFILE
+/* Define if your user name is msevior */
+/* #undef LOGFILE */
+
+#ifdef LOGFILE
+FILE * getlogfile(void);
+#endif
 
 class XAP_StringSet;
 class AV_View;
 class GR_Image;
+class AP_Args;
 
-class AP_UnixApp : public XAP_UNIXBASEAPP
+class AP_UnixApp : public AP_App
 {
 public:
 	AP_UnixApp(XAP_Args * pArgs, const char * szAppName);
 	virtual ~AP_UnixApp();
 
-	virtual bool					initialize(void);
+	virtual bool					initialize(bool has_display);
 	virtual XAP_Frame *				newFrame(void);
 	virtual bool					forgetFrame(XAP_Frame * pFrame);
 	virtual bool					shutdown(void);
@@ -58,12 +70,12 @@ public:
 									       const XML_Char * szKey, const XML_Char ** pszValue) const;
 	virtual const XAP_StringSet *	                getStringSet(void) const;
 	virtual const char *			        getAbiSuiteAppDir(void) const;
-	virtual void					copyToClipboard(PD_DocumentRange * pDocRange);
+	virtual const char * 					getAbiSuiteAppGladeDir(void) const;
+
+	virtual void					copyToClipboard(PD_DocumentRange * pDocRange, bool bUseClipboard = true);
 	virtual void					pasteFromClipboard(PD_DocumentRange * pDocRange, bool bUseClipboard, bool bHonorFormatting = true);
 	virtual bool					canPasteFromClipboard(void);
 	
-	virtual bool					parseCommandLine(void);
-
 	virtual void					setSelectionStatus(AV_View * pView);
 
 	/*!
@@ -85,11 +97,19 @@ public:
 														const char **pszFormatFound);
 	virtual void					cacheCurrentSelection(AV_View *);
 
-	static int main (const char * szAppName, int argc, char ** argv);
+	static int main (const char * szAppName, int argc, const char ** argv);
 
 	void							catchSignals(int sig_num);
 	void loadAllPlugins ();
 
+	virtual void errorMsgBadArg(AP_Args * Args, int nextopt);
+	virtual void errorMsgBadFile(XAP_Frame * pFrame, const char * file, 
+								 UT_Error error);
+	virtual void initPopt (AP_Args *);
+	virtual bool doWindowlessArgs (const AP_Args *);
+	virtual XAP_Frame * newFrame(AP_App *);
+	bool makePngPreview(const char * pszInFile, const char * pszPNGFile, UT_sint32 iWidth, UT_sint32 iHeight);
+
 protected:	// JCA: Why in the hell we have so many (any) protected variables?
 	static GR_Image*		_showSplash(UT_uint32);
 
