@@ -48,7 +48,7 @@ dcl(MSG_IE_CouldNotWrite,		"Could not write to file %s")
 dcl(MSG_SpellSelectionDone,		"AbiWord finished checking the selection.")
 dcl(MSG_SpellDone,				"The spelling check is complete.")
 dcl(MSG_PrintStatus,			"Printing page %d of %d")
-dcl(MSG_RevertFile, "Revert file to last unsaved state?")
+dcl(MSG_RevertFile, "Revert file to last saved state?")
 dcl(MSG_PrintingDoc, "Printing Document..")
 dcl(MSG_NoBreakInsideTable, "Can not insert a Break inside a table")
 dcl(MSG_NoBreakInsideFrame, "Can not insert a Break inside a text box")
@@ -284,8 +284,8 @@ dcl(DLG_Para_SpacingAtLeast,	"At least")
 dcl(DLG_Para_SpacingExactly,	"Exactly")
 dcl(DLG_Para_SpacingMultiple,	"Multiple")
 
-dcl(DLG_Para_TabLabelIndentsAndSpacing, "&Indents and Spacing")
-dcl(DLG_Para_TabLabelLineAndPageBreaks, "Line and &Page Breaks")
+dcl(DLG_Para_TabLabelIndentsAndSpacing, "Indents and Spacing")
+dcl(DLG_Para_TabLabelLineAndPageBreaks, "Line and Page Breaks")
 
 dcl(DLG_Para_LabelAlignment,	"Ali&gnment:")
 dcl(DLG_Para_LabelBy,			"B&y:")
